Struct
QmiMessageWmsGetTransportNetworkRegistrationStatusInput
since: 1.38
Description [src]
struct QmiMessageWmsGetTransportNetworkRegistrationStatusInput {
/* No available fields */
}
The QmiMessageWmsGetTransportNetworkRegistrationStatusInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Constructors
qmi_message_wms_get_transport_network_registration_status_input_new
Allocates a new QmiMessageWmsGetTransportNetworkRegistrationStatusInput.
since: 1.38
Instance methods
qmi_message_wms_get_transport_network_registration_status_input_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_wms_get_transport_network_registration_status_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38